@@ -52,7 +52,7 @@ CronOptions::CronOptions(TQWidget *parent) :
 	TQString description= i18n("<qt><p>These files will be analyzed to display <b>Cron Logs</b> (planned tasks logs). This list also determines the order in which the files are read.</p></qt>");
 	fileList=new SpecificFileList(this, description);
 	
-	connect(fileList, TQT_SIGNAL(fileListChanged(int)), this, TQT_SLOT(slotFileListChanged(int)));
+	connect(fileList, TQ_SIGNAL(fileListChanged(int)), this, TQ_SLOT(slotFileListChanged(int)));
 
 	readConfig();
 	
