@@ -46,7 +46,7 @@ void FindManager::slotFind() {
 		kdDebug() << "KFindDialog creation" << endl;
 		//TODO Save the Find options to Config file
 		findDialog=new KFindDialog(false, main, "find_dialog");
-		connect(findDialog, TQT_SIGNAL(okClicked()), this, TQT_SLOT(slotFindNext()));
+		connect(findDialog, TQ_SIGNAL(okClicked()), this, TQ_SLOT(slotFindNext()));
 	
 		findDialog->show();
 	}
@@ -79,8 +79,8 @@ void FindManager::slotFirstFind() {
 	
 	//This creates a find-next-prompt dialog if needed.
 	findManager=new KFind(findDialog->pattern(), findDialog->options(), main, findDialog);
-	connect(findManager, TQT_SIGNAL(highlight(const TQString&, int, int)), this, TQT_SLOT(highlightSearch(const TQString&, int, int)));
-	connect(findManager, TQT_SIGNAL(findNext()), this, TQT_SLOT(slotFindNext()));
+	connect(findManager, TQ_SIGNAL(highlight(const TQString&, int, int)), this, TQ_SLOT(highlightSearch(const TQString&, int, int)));
+	connect(findManager, TQ_SIGNAL(findNext()), this, TQ_SLOT(slotFindNext()));
 	
 	//Do not keep the KFindDialog open
 	findDialog->hide();
