@@ -42,7 +42,7 @@
  */
 class LoadingDialog : public KProgressDialog {
 
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 	public:
