@@ -36,7 +36,7 @@
 #include "logLevel.h"
 
 class MailOptions : public TQWidget {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		MailOptions(TQWidget *parent = 0);
