@@ -48,7 +48,7 @@ class View;
  */
 class Reader : public TQObject {
 	
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 	public:
